<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyCaseManagementRequest;
use App\Http\Requests\StoreCaseManagementRequest;
use App\Http\Requests\UpdateCaseManagementRequest;
use App\Models\CaseManagement;
use App\Models\TrainingLevel;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;

class CaseManagementController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('case_management_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $user_id = \Auth::user()->id;

        $rolee = \Auth::user()->roles->first();
        
  
        
        
        if($rolee->id == 1)
        {
            $caseManagements = CaseManagement::with(['physician', 'nurse', 'paramedic', 'rapid_risk_assessments', 'clinical_management_advice_and_recommendations', 'icp_in_the_care_facility', 'monitoring_system', 'epidemic_survey', 'determination_of_disease_status', 'epidemiological_studies', 'study_protocols', 'data_collection_tools', 'user'])
            // ->where('user_id', $user_id)
            ->get();
        }
        else
        {
            $caseManagements = CaseManagement::with(['physician', 'nurse', 'paramedic', 'rapid_risk_assessments', 'clinical_management_advice_and_recommendations', 'icp_in_the_care_facility', 'monitoring_system', 'epidemic_survey', 'determination_of_disease_status', 'epidemiological_studies', 'study_protocols', 'data_collection_tools', 'user'])
            ->where('user_id', $user_id)
            ->get();
        }
        

        $training_levels = TrainingLevel::get();

        $users = User::get();

        return view('admin.caseManagements.index', compact('caseManagements', 'training_levels', 'users'));
    }

    public function create()
    {
        abort_if(Gate::denies('case_management_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $physicians = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $nurses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $paramedics = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $rapid_risk_assessments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $clinical_management_advice_and_recommendations = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $icp_in_the_care_facilities = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $monitoring_systems = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $epidemic_surveys = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $determination_of_disease_statuses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $epidemiological_studies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $study_protocols = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $data_collection_tools = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.caseManagements.create', compact('clinical_management_advice_and_recommendations', 'data_collection_tools', 'determination_of_disease_statuses', 'epidemic_surveys', 'epidemiological_studies', 'icp_in_the_care_facilities', 'monitoring_systems', 'nurses', 'paramedics', 'physicians', 'rapid_risk_assessments', 'study_protocols', 'users'));
    }

    public function store(StoreCaseManagementRequest $request)
    {
        $caseManagement = CaseManagement::create($request->all());

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $caseManagement->id]);
        }

        return redirect()->route('admin.case-managements.index');
    }

    public function edit(CaseManagement $caseManagement)
    {
        abort_if(Gate::denies('case_management_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $physicians = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $nurses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $paramedics = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $rapid_risk_assessments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $clinical_management_advice_and_recommendations = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $icp_in_the_care_facilities = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $monitoring_systems = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $epidemic_surveys = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $determination_of_disease_statuses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $epidemiological_studies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $study_protocols = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $data_collection_tools = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $caseManagement->load('physician', 'nurse', 'paramedic', 'rapid_risk_assessments', 'clinical_management_advice_and_recommendations', 'icp_in_the_care_facility', 'monitoring_system', 'epidemic_survey', 'determination_of_disease_status', 'epidemiological_studies', 'study_protocols', 'data_collection_tools', 'user');

        return view('admin.caseManagements.edit', compact('caseManagement', 'clinical_management_advice_and_recommendations', 'data_collection_tools', 'determination_of_disease_statuses', 'epidemic_surveys', 'epidemiological_studies', 'icp_in_the_care_facilities', 'monitoring_systems', 'nurses', 'paramedics', 'physicians', 'rapid_risk_assessments', 'study_protocols', 'users'));
    }

    public function update(UpdateCaseManagementRequest $request, CaseManagement $caseManagement)
    {
        $caseManagement->update($request->all());

        return redirect()->route('admin.case-managements.index');
    }

    public function show(CaseManagement $caseManagement)
    {
        abort_if(Gate::denies('case_management_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $caseManagement->load('physician', 'nurse', 'paramedic', 'rapid_risk_assessments', 'clinical_management_advice_and_recommendations', 'icp_in_the_care_facility', 'monitoring_system', 'epidemic_survey', 'determination_of_disease_status', 'epidemiological_studies', 'study_protocols', 'data_collection_tools', 'user');

        return view('admin.caseManagements.show', compact('caseManagement'));
    }

    public function destroy(CaseManagement $caseManagement)
    {
        abort_if(Gate::denies('case_management_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $caseManagement->delete();

        return back();
    }

    public function massDestroy(MassDestroyCaseManagementRequest $request)
    {
        CaseManagement::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {
        abort_if(Gate::denies('case_management_create') && Gate::denies('case_management_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $model         = new CaseManagement();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }
}
