<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyDataManagementRequest;
use App\Http\Requests\StoreDataManagementRequest;
use App\Http\Requests\UpdateDataManagementRequest;
use App\Models\DataManagement;
use App\Models\TrainingLevel;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;

class DataManagementController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('data_management_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $user_id = \Auth::user()->id;

        $rolee = \Auth::user()->roles->first();
        
  
        
        
        if($rolee->id == 1)
        {
        $dataManagements = DataManagement::with(['quantitative_data', 'excel', 'access', 'sas', 'spss', 'status', 'r', 'epi_info', 'monitoring_database', 'qualitative_data', 'data_visualization', 'geographic_information_system_gis', 'user'])
        // ->where('user_id', \Auth::user()->id)
        ->get();
    }
    else
    {
        $dataManagements = DataManagement::with(['quantitative_data', 'excel', 'access', 'sas', 'spss', 'status', 'r', 'epi_info', 'monitoring_database', 'qualitative_data', 'data_visualization', 'geographic_information_system_gis', 'user'])
        ->where('user_id', \Auth::user()->id)
        ->get();
    }
        
        $training_levels = TrainingLevel::get();

        $users = User::get();

        return view('admin.dataManagements.index', compact('dataManagements', 'training_levels', 'users'));
    }

    public function create()
    {
        abort_if(Gate::denies('data_management_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $quantitative_datas = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $excels = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $accesses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $sas = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $spsses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $statuses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $rs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $epi_infos = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $monitoring_databases = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $qualitative_datas = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $data_visualizations = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $geographic_information_system_gis = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.dataManagements.create', compact('accesses', 'data_visualizations', 'epi_infos', 'excels', 'geographic_information_system_gis', 'monitoring_databases', 'qualitative_datas', 'quantitative_datas', 'rs', 'sas', 'spsses', 'statuses', 'users'));
    }

    public function store(StoreDataManagementRequest $request)
    {
        $dataManagement = DataManagement::create($request->all());

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $dataManagement->id]);
        }

        return redirect()->route('admin.data-managements.index');
    }

    public function edit(DataManagement $dataManagement)
    {
        abort_if(Gate::denies('data_management_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $quantitative_datas = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $excels = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $accesses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $sas = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $spsses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $statuses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $rs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $epi_infos = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $monitoring_databases = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $qualitative_datas = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $data_visualizations = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $geographic_information_system_gis = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $dataManagement->load('quantitative_data', 'excel', 'access', 'sas', 'spss', 'status', 'r', 'epi_info', 'monitoring_database', 'qualitative_data', 'data_visualization', 'geographic_information_system_gis', 'user');

        return view('admin.dataManagements.edit', compact('accesses', 'dataManagement', 'data_visualizations', 'epi_infos', 'excels', 'geographic_information_system_gis', 'monitoring_databases', 'qualitative_datas', 'quantitative_datas', 'rs', 'sas', 'spsses', 'statuses', 'users'));
    }

    public function update(UpdateDataManagementRequest $request, DataManagement $dataManagement)
    {
        $dataManagement->update($request->all());

        return redirect()->route('admin.data-managements.index');
    }

    public function show(DataManagement $dataManagement)
    {
        abort_if(Gate::denies('data_management_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $dataManagement->load('quantitative_data', 'excel', 'access', 'sas', 'spss', 'status', 'r', 'epi_info', 'monitoring_database', 'qualitative_data', 'data_visualization', 'geographic_information_system_gis', 'user');

        return view('admin.dataManagements.show', compact('dataManagement'));
    }

    public function destroy(DataManagement $dataManagement)
    {
        abort_if(Gate::denies('data_management_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $dataManagement->delete();

        return back();
    }

    public function massDestroy(MassDestroyDataManagementRequest $request)
    {
        DataManagement::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {
        abort_if(Gate::denies('data_management_create') && Gate::denies('data_management_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $model         = new DataManagement();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }
}
