<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyEmergencyLogisticRequest;
use App\Http\Requests\StoreEmergencyLogisticRequest;
use App\Http\Requests\UpdateEmergencyLogisticRequest;
use App\Models\EmergencyLogistic;
use App\Models\TrainingLevel;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class EmergencyLogisticsController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('emergency_logistic_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rolee = \Auth::user()->roles->first();
        
        if($rolee->id == 1)
        {
            $emergencyLogistics = EmergencyLogistic::with(['shipping_and_receiving', 'sample_packaging', 'inventory_management', 'travel_coordinator', 'fleet_management', 'moving_resources_to_the_field', 'deployer_training_resources', 'eoc_logistics_emergency_operations_center', 'user'])
            //->where('user_id', \Auth::user()->id)
            ->get();
        }
        else{
            $emergencyLogistics = EmergencyLogistic::with(['shipping_and_receiving', 'sample_packaging', 'inventory_management', 'travel_coordinator', 'fleet_management', 'moving_resources_to_the_field', 'deployer_training_resources', 'eoc_logistics_emergency_operations_center', 'user'])
            ->where('user_id', \Auth::user()->id)
            ->get();
        }
        
        $training_levels = TrainingLevel::get();

        $users = User::get();

        return view('admin.emergencyLogistics.index', compact('emergencyLogistics', 'training_levels', 'users'));
    }

    public function create()
    {
        abort_if(Gate::denies('emergency_logistic_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $shipping_and_receivings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $sample_packagings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $inventory_managements = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $travel_coordinators = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $fleet_managements = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $moving_resources_to_the_fields = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $deployer_training_resources = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $eoc_logistics_emergency_operations_centers = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.emergencyLogistics.create', compact('deployer_training_resources', 'eoc_logistics_emergency_operations_centers', 'fleet_managements', 'inventory_managements', 'moving_resources_to_the_fields', 'sample_packagings', 'shipping_and_receivings', 'travel_coordinators', 'users'));
    }

    public function store(StoreEmergencyLogisticRequest $request)
    {
        $emergencyLogistic = EmergencyLogistic::create($request->all());

        return redirect()->route('admin.emergency-logistics.index');
    }

    public function edit(EmergencyLogistic $emergencyLogistic)
    {
        abort_if(Gate::denies('emergency_logistic_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $shipping_and_receivings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $sample_packagings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $inventory_managements = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $travel_coordinators = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $fleet_managements = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $moving_resources_to_the_fields = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $deployer_training_resources = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $eoc_logistics_emergency_operations_centers = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $emergencyLogistic->load('shipping_and_receiving', 'sample_packaging', 'inventory_management', 'travel_coordinator', 'fleet_management', 'moving_resources_to_the_field', 'deployer_training_resources', 'eoc_logistics_emergency_operations_center', 'user');

        return view('admin.emergencyLogistics.edit', compact('deployer_training_resources', 'emergencyLogistic', 'eoc_logistics_emergency_operations_centers', 'fleet_managements', 'inventory_managements', 'moving_resources_to_the_fields', 'sample_packagings', 'shipping_and_receivings', 'travel_coordinators', 'users'));
    }

    public function update(UpdateEmergencyLogisticRequest $request, EmergencyLogistic $emergencyLogistic)
    {
        $emergencyLogistic->update($request->all());

        return redirect()->route('admin.emergency-logistics.index');
    }

    public function show(EmergencyLogistic $emergencyLogistic)
    {
        abort_if(Gate::denies('emergency_logistic_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $emergencyLogistic->load('shipping_and_receiving', 'sample_packaging', 'inventory_management', 'travel_coordinator', 'fleet_management', 'moving_resources_to_the_field', 'deployer_training_resources', 'eoc_logistics_emergency_operations_center', 'user');

        return view('admin.emergencyLogistics.show', compact('emergencyLogistic'));
    }

    public function destroy(EmergencyLogistic $emergencyLogistic)
    {
        abort_if(Gate::denies('emergency_logistic_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $emergencyLogistic->delete();

        return back();
    }

    public function massDestroy(MassDestroyEmergencyLogisticRequest $request)
    {
        EmergencyLogistic::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
