<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyEmergencyResponseRequest;
use App\Http\Requests\StoreEmergencyResponseRequest;
use App\Http\Requests\UpdateEmergencyResponseRequest;
use App\Models\DiseaseEmergency;
use App\Models\EmergencyResponse;
use App\Models\TrainingLevel;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class EmergencyResponseController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('emergency_response_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $emergencyResponses = EmergencyResponse::with(['domestic_emergency_response', 'cross_sectoral', 'response_to_international_emergencies', 'eoc_ims', 'vaccination_campaigns', 'emergency_leadership_role', 'multi_sectoral_emergency_response_plans', 'emergency_diseases'])->get();

        $training_levels = TrainingLevel::get();

        $disease_emergencies = DiseaseEmergency::get();

        return view('admin.emergencyResponses.index', compact('disease_emergencies', 'emergencyResponses', 'training_levels'));
    }

    public function create()
    {
        abort_if(Gate::denies('emergency_response_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $domestic_emergency_responses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $cross_sectorals = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $response_to_international_emergencies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $eoc_ims = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $vaccination_campaigns = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $emergency_leadership_roles = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $multi_sectoral_emergency_response_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $emergency_diseases = DiseaseEmergency::pluck('name', 'id');

        return view('admin.emergencyResponses.create', compact('cross_sectorals', 'domestic_emergency_responses', 'emergency_diseases', 'emergency_leadership_roles', 'eoc_ims', 'multi_sectoral_emergency_response_plans', 'response_to_international_emergencies', 'vaccination_campaigns'));
    }

    public function store(StoreEmergencyResponseRequest $request)
    {
        $emergencyResponse = EmergencyResponse::create($request->all());
        $emergencyResponse->emergency_diseases()->sync($request->input('emergency_diseases', []));

        return redirect()->route('admin.emergency-responses.index');
    }

    public function edit(EmergencyResponse $emergencyResponse)
    {
        abort_if(Gate::denies('emergency_response_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $domestic_emergency_responses = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $cross_sectorals = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $response_to_international_emergencies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $eoc_ims = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $vaccination_campaigns = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $emergency_leadership_roles = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $multi_sectoral_emergency_response_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $emergency_diseases = DiseaseEmergency::pluck('name', 'id');

        $emergencyResponse->load('domestic_emergency_response', 'cross_sectoral', 'response_to_international_emergencies', 'eoc_ims', 'vaccination_campaigns', 'emergency_leadership_role', 'multi_sectoral_emergency_response_plans', 'emergency_diseases');

        return view('admin.emergencyResponses.edit', compact('cross_sectorals', 'domestic_emergency_responses', 'emergencyResponse', 'emergency_diseases', 'emergency_leadership_roles', 'eoc_ims', 'multi_sectoral_emergency_response_plans', 'response_to_international_emergencies', 'vaccination_campaigns'));
    }

    public function update(UpdateEmergencyResponseRequest $request, EmergencyResponse $emergencyResponse)
    {
        $emergencyResponse->update($request->all());
        $emergencyResponse->emergency_diseases()->sync($request->input('emergency_diseases', []));

        return redirect()->route('admin.emergency-responses.index');
    }

    public function show(EmergencyResponse $emergencyResponse)
    {
        abort_if(Gate::denies('emergency_response_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $emergencyResponse->load('domestic_emergency_response', 'cross_sectoral', 'response_to_international_emergencies', 'eoc_ims', 'vaccination_campaigns', 'emergency_leadership_role', 'multi_sectoral_emergency_response_plans', 'emergency_diseases');

        return view('admin.emergencyResponses.show', compact('emergencyResponse'));
    }

    public function destroy(EmergencyResponse $emergencyResponse)
    {
        abort_if(Gate::denies('emergency_response_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $emergencyResponse->delete();

        return back();
    }

    public function massDestroy(MassDestroyEmergencyResponseRequest $request)
    {
        EmergencyResponse::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
