<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyHazardousMaterialsExperienceRequest;
use App\Http\Requests\StoreHazardousMaterialsExperienceRequest;
use App\Http\Requests\UpdateHazardousMaterialsExperienceRequest;
use App\Models\HazardousMaterialsExperience;
use App\Models\TrainingLevel;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class HazardousMaterialsExperienceController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('hazardous_materials_experience_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $hazardousMaterialsExperiences = HazardousMaterialsExperience::with(['certified_hazardous_materials_manager_chmm', 'certified_industrial_hygienist_cih', 'hazmat_specialist_training', 'record_keeping', 'hazardous_materials_management_y_n_program', 'medical_waste_plans', 'spill_response_plans', 'hazardous_waste_reduction_plans', 'hazardous_waste_contingency_plans', 'stormwater_y_n_plans', 'occupational_health_and_safety_y_n_programs', 'radiation_protection_plan', 'collection_segregation_and_transport_of_hazardous_waste', 'training_others_on_hazardous_waste'])->get();

        $training_levels = TrainingLevel::get();

        return view('admin.hazardousMaterialsExperiences.index', compact('hazardousMaterialsExperiences', 'training_levels'));
    }

    public function create()
    {
        abort_if(Gate::denies('hazardous_materials_experience_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $certified_hazardous_materials_manager_chmms = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $certified_industrial_hygienist_cihs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $hazmat_specialist_trainings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $record_keepings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $hazardous_materials_management_y_n_programs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $medical_waste_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $spill_response_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $hazardous_waste_reduction_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $hazardous_waste_contingency_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $stormwater_y_n_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $occupational_health_and_safety_y_n_programs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $radiation_protection_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $collection_segregation_and_transport_of_hazardous_wastes = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $training_others_on_hazardous_wastes = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.hazardousMaterialsExperiences.create', compact('certified_hazardous_materials_manager_chmms', 'certified_industrial_hygienist_cihs', 'collection_segregation_and_transport_of_hazardous_wastes', 'hazardous_materials_management_y_n_programs', 'hazardous_waste_contingency_plans', 'hazardous_waste_reduction_plans', 'hazmat_specialist_trainings', 'medical_waste_plans', 'occupational_health_and_safety_y_n_programs', 'radiation_protection_plans', 'record_keepings', 'spill_response_plans', 'stormwater_y_n_plans', 'training_others_on_hazardous_wastes'));
    }

    public function store(StoreHazardousMaterialsExperienceRequest $request)
    {
        $hazardousMaterialsExperience = HazardousMaterialsExperience::create($request->all());

        return redirect()->route('admin.hazardous-materials-experiences.index');
    }

    public function edit(HazardousMaterialsExperience $hazardousMaterialsExperience)
    {
        abort_if(Gate::denies('hazardous_materials_experience_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $certified_hazardous_materials_manager_chmms = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $certified_industrial_hygienist_cihs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $hazmat_specialist_trainings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $record_keepings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $hazardous_materials_management_y_n_programs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $medical_waste_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $spill_response_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $hazardous_waste_reduction_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $hazardous_waste_contingency_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $stormwater_y_n_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $occupational_health_and_safety_y_n_programs = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $radiation_protection_plans = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $collection_segregation_and_transport_of_hazardous_wastes = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $training_others_on_hazardous_wastes = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $hazardousMaterialsExperience->load('certified_hazardous_materials_manager_chmm', 'certified_industrial_hygienist_cih', 'hazmat_specialist_training', 'record_keeping', 'hazardous_materials_management_y_n_program', 'medical_waste_plans', 'spill_response_plans', 'hazardous_waste_reduction_plans', 'hazardous_waste_contingency_plans', 'stormwater_y_n_plans', 'occupational_health_and_safety_y_n_programs', 'radiation_protection_plan', 'collection_segregation_and_transport_of_hazardous_waste', 'training_others_on_hazardous_waste');

        return view('admin.hazardousMaterialsExperiences.edit', compact('certified_hazardous_materials_manager_chmms', 'certified_industrial_hygienist_cihs', 'collection_segregation_and_transport_of_hazardous_wastes', 'hazardousMaterialsExperience', 'hazardous_materials_management_y_n_programs', 'hazardous_waste_contingency_plans', 'hazardous_waste_reduction_plans', 'hazmat_specialist_trainings', 'medical_waste_plans', 'occupational_health_and_safety_y_n_programs', 'radiation_protection_plans', 'record_keepings', 'spill_response_plans', 'stormwater_y_n_plans', 'training_others_on_hazardous_wastes'));
    }

    public function update(UpdateHazardousMaterialsExperienceRequest $request, HazardousMaterialsExperience $hazardousMaterialsExperience)
    {
        $hazardousMaterialsExperience->update($request->all());

        return redirect()->route('admin.hazardous-materials-experiences.index');
    }

    public function show(HazardousMaterialsExperience $hazardousMaterialsExperience)
    {
        abort_if(Gate::denies('hazardous_materials_experience_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $hazardousMaterialsExperience->load('certified_hazardous_materials_manager_chmm', 'certified_industrial_hygienist_cih', 'hazmat_specialist_training', 'record_keeping', 'hazardous_materials_management_y_n_program', 'medical_waste_plans', 'spill_response_plans', 'hazardous_waste_reduction_plans', 'hazardous_waste_contingency_plans', 'stormwater_y_n_plans', 'occupational_health_and_safety_y_n_programs', 'radiation_protection_plan', 'collection_segregation_and_transport_of_hazardous_waste', 'training_others_on_hazardous_waste');

        return view('admin.hazardousMaterialsExperiences.show', compact('hazardousMaterialsExperience'));
    }

    public function destroy(HazardousMaterialsExperience $hazardousMaterialsExperience)
    {
        abort_if(Gate::denies('hazardous_materials_experience_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $hazardousMaterialsExperience->delete();

        return back();
    }

    public function massDestroy(MassDestroyHazardousMaterialsExperienceRequest $request)
    {
        HazardousMaterialsExperience::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
