<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyInfectionPreventControlRequest;
use App\Http\Requests\StoreInfectionPreventControlRequest;
use App\Http\Requests\UpdateInfectionPreventControlRequest;
use App\Models\InfectionPreventControl;
use App\Models\TrainingLevel;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class InfectionPreventControlController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('infection_prevent_control_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $infectionPreventControls = InfectionPreventControl::with(['in_healthcare_settings', 'in_a_non_medical', 'outbreak_investigations', 'facility_assessments', 'developing_infection_prevention', 'infection_prevention_and_control', 'quality_improvement', 'ppe', 'point_of_entry_border_health', 'poc_non_border', 'rsi'])->get();

        $training_levels = TrainingLevel::get();

        return view('admin.infectionPreventControls.index', compact('infectionPreventControls', 'training_levels'));
    }

    public function create()
    {
        abort_if(Gate::denies('infection_prevent_control_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $in_healthcare_settings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $in_a_non_medicals = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $outbreak_investigations = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $facility_assessments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $developing_infection_preventions = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $infection_prevention_and_controls = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $quality_improvements = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $ppes = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $point_of_entry_border_healths = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $poc_non_borders = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $rsis = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.infectionPreventControls.create', compact('developing_infection_preventions', 'facility_assessments', 'in_a_non_medicals', 'in_healthcare_settings', 'infection_prevention_and_controls', 'outbreak_investigations', 'poc_non_borders', 'point_of_entry_border_healths', 'ppes', 'quality_improvements', 'rsis'));
    }

    public function store(StoreInfectionPreventControlRequest $request)
    {
        $infectionPreventControl = InfectionPreventControl::create($request->all());

        return redirect()->route('admin.infection-prevent-controls.index');
    }

    public function edit(InfectionPreventControl $infectionPreventControl)
    {
        abort_if(Gate::denies('infection_prevent_control_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $in_healthcare_settings = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $in_a_non_medicals = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $outbreak_investigations = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $facility_assessments = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $developing_infection_preventions = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $infection_prevention_and_controls = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $quality_improvements = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $ppes = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $point_of_entry_border_healths = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $poc_non_borders = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $rsis = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $infectionPreventControl->load('in_healthcare_settings', 'in_a_non_medical', 'outbreak_investigations', 'facility_assessments', 'developing_infection_prevention', 'infection_prevention_and_control', 'quality_improvement', 'ppe', 'point_of_entry_border_health', 'poc_non_border', 'rsi');

        return view('admin.infectionPreventControls.edit', compact('developing_infection_preventions', 'facility_assessments', 'in_a_non_medicals', 'in_healthcare_settings', 'infectionPreventControl', 'infection_prevention_and_controls', 'outbreak_investigations', 'poc_non_borders', 'point_of_entry_border_healths', 'ppes', 'quality_improvements', 'rsis'));
    }

    public function update(UpdateInfectionPreventControlRequest $request, InfectionPreventControl $infectionPreventControl)
    {
        $infectionPreventControl->update($request->all());

        return redirect()->route('admin.infection-prevent-controls.index');
    }

    public function show(InfectionPreventControl $infectionPreventControl)
    {
        abort_if(Gate::denies('infection_prevent_control_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $infectionPreventControl->load('in_healthcare_settings', 'in_a_non_medical', 'outbreak_investigations', 'facility_assessments', 'developing_infection_prevention', 'infection_prevention_and_control', 'quality_improvement', 'ppe', 'point_of_entry_border_health', 'poc_non_border', 'rsi');

        return view('admin.infectionPreventControls.show', compact('infectionPreventControl'));
    }

    public function destroy(InfectionPreventControl $infectionPreventControl)
    {
        abort_if(Gate::denies('infection_prevent_control_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $infectionPreventControl->delete();

        return back();
    }

    public function massDestroy(MassDestroyInfectionPreventControlRequest $request)
    {
        InfectionPreventControl::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
