<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyLaboratoryExperienceRequest;
use App\Http\Requests\StoreLaboratoryExperienceRequest;
use App\Http\Requests\UpdateLaboratoryExperienceRequest;
use App\Models\AgencyRole;
use App\Models\LaboratoryExperience;
use App\Models\TrainingLevel;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class LaboratoryExperienceController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('laboratory_experience_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $laboratoryExperiences = LaboratoryExperience::with(['user', 'biosafety_experience', 'laboratory_quality_management', 'sample_reception_and_acquisition', 'sample_transport', 'antimicrobial', 'parasitology', 'mycology', 'clinical_chemistry', 'blood_bank', 'molecular_methods', 'advanced_molecular_detection_dma', 'viral_culture', 'serology', 'bsl_3', 'bacterial_culture', 'phlebotomy_venipuncture', 'laboratory_training_instructor', 'laboratory_supervisor_experience', 'laboratory_field_intervention_coordinator'])
        ->where('user_id', \Auth::user()->id)
        ->get();

        $users = User::get();

        $training_levels = TrainingLevel::get();

        $agency_roles = AgencyRole::get();

        return view('admin.laboratoryExperiences.index', compact('agency_roles', 'laboratoryExperiences', 'training_levels', 'users'));
    }

    public function create()
    {
        abort_if(Gate::denies('laboratory_experience_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $biosafety_experiences = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $laboratory_quality_managements = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $sample_reception_and_acquisitions = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $sample_transports = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $antimicrobials = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $parasitologies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $mycologies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $clinical_chemistries = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $blood_banks = AgencyRole::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $molecular_methods = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $advanced_molecular_detection_dmas = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $viral_cultures = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $serologies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $bsl_3s = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $bacterial_cultures = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $phlebotomy_venipunctures = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $laboratory_training_instructors = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $laboratory_supervisor_experiences = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $laboratory_field_intervention_coordinators = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.laboratoryExperiences.create', compact('advanced_molecular_detection_dmas', 'antimicrobials', 'bacterial_cultures', 'biosafety_experiences', 'blood_banks', 'bsl_3s', 'clinical_chemistries', 'laboratory_field_intervention_coordinators', 'laboratory_quality_managements', 'laboratory_supervisor_experiences', 'laboratory_training_instructors', 'molecular_methods', 'mycologies', 'parasitologies', 'phlebotomy_venipunctures', 'sample_reception_and_acquisitions', 'sample_transports', 'serologies', 'users', 'viral_cultures'));
    }

    public function store(StoreLaboratoryExperienceRequest $request)
    {
        $laboratoryExperience = LaboratoryExperience::create($request->all());

        return redirect()->route('admin.laboratory-experiences.index');
    }

    public function edit(LaboratoryExperience $laboratoryExperience)
    {
        abort_if(Gate::denies('laboratory_experience_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $biosafety_experiences = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $laboratory_quality_managements = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $sample_reception_and_acquisitions = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $sample_transports = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $antimicrobials = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $parasitologies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $mycologies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $clinical_chemistries = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $blood_banks = AgencyRole::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $molecular_methods = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $advanced_molecular_detection_dmas = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $viral_cultures = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $serologies = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $bsl_3s = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $bacterial_cultures = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $phlebotomy_venipunctures = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $laboratory_training_instructors = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $laboratory_supervisor_experiences = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $laboratory_field_intervention_coordinators = TrainingLevel::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $laboratoryExperience->load('user', 'biosafety_experience', 'laboratory_quality_management', 'sample_reception_and_acquisition', 'sample_transport', 'antimicrobial', 'parasitology', 'mycology', 'clinical_chemistry', 'blood_bank', 'molecular_methods', 'advanced_molecular_detection_dma', 'viral_culture', 'serology', 'bsl_3', 'bacterial_culture', 'phlebotomy_venipuncture', 'laboratory_training_instructor', 'laboratory_supervisor_experience', 'laboratory_field_intervention_coordinator');

        return view('admin.laboratoryExperiences.edit', compact('advanced_molecular_detection_dmas', 'antimicrobials', 'bacterial_cultures', 'biosafety_experiences', 'blood_banks', 'bsl_3s', 'clinical_chemistries', 'laboratoryExperience', 'laboratory_field_intervention_coordinators', 'laboratory_quality_managements', 'laboratory_supervisor_experiences', 'laboratory_training_instructors', 'molecular_methods', 'mycologies', 'parasitologies', 'phlebotomy_venipunctures', 'sample_reception_and_acquisitions', 'sample_transports', 'serologies', 'users', 'viral_cultures'));
    }

    public function update(UpdateLaboratoryExperienceRequest $request, LaboratoryExperience $laboratoryExperience)
    {
        $laboratoryExperience->update($request->all());

        return redirect()->route('admin.laboratory-experiences.index');
    }

    public function show(LaboratoryExperience $laboratoryExperience)
    {
        abort_if(Gate::denies('laboratory_experience_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $laboratoryExperience->load('user', 'biosafety_experience', 'laboratory_quality_management', 'sample_reception_and_acquisition', 'sample_transport', 'antimicrobial', 'parasitology', 'mycology', 'clinical_chemistry', 'blood_bank', 'molecular_methods', 'advanced_molecular_detection_dma', 'viral_culture', 'serology', 'bsl_3', 'bacterial_culture', 'phlebotomy_venipuncture', 'laboratory_training_instructor', 'laboratory_supervisor_experience', 'laboratory_field_intervention_coordinator');

        return view('admin.laboratoryExperiences.show', compact('laboratoryExperience'));
    }

    public function destroy(LaboratoryExperience $laboratoryExperience)
    {
        abort_if(Gate::denies('laboratory_experience_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $laboratoryExperience->delete();

        return back();
    }

    public function massDestroy(MassDestroyLaboratoryExperienceRequest $request)
    {
        LaboratoryExperience::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
