<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyRegisterRequest;
use App\Http\Requests\StoreRegisterRequest;
use App\Http\Requests\UpdateRegisterRequest;
use App\Models\Country;
use App\Models\Qualification;
use App\Models\Register;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;

class RegisterController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('register_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $registers = Register::with(['country_residence', 'qualification', 'user'])->get();

        $countries = Country::get();

        $qualifications = Qualification::get();

        $users = User::get();

        return view('admin.registers.index', compact('countries', 'qualifications', 'registers', 'users'));
    }

    public function create()
    {
        abort_if(Gate::denies('register_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $country_residences = Country::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $qualifications = Qualification::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.registers.create', compact('country_residences', 'qualifications', 'users'));
    }

    public function store(StoreRegisterRequest $request)
    {
        $register = Register::create($request->all());

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $register->id]);
        }

        return redirect()->route('admin.registers.index');
    }

    public function edit(Register $register)
    {
        abort_if(Gate::denies('register_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $country_residences = Country::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $qualifications = Qualification::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $register->load('country_residence', 'qualification', 'user');

        return view('admin.registers.edit', compact('country_residences', 'qualifications', 'register', 'users'));
    }

    public function update(UpdateRegisterRequest $request, Register $register)
    {
        $register->update($request->all());

        return redirect()->route('admin.registers.index');
    }

    public function show(Register $register)
    {
        abort_if(Gate::denies('register_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $register->load('country_residence', 'qualification', 'user');

        return view('admin.registers.show', compact('register'));
    }

    public function destroy(Register $register)
    {
        abort_if(Gate::denies('register_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $register->delete();

        return back();
    }

    public function massDestroy(MassDestroyRegisterRequest $request)
    {
        Register::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {
        abort_if(Gate::denies('register_create') && Gate::denies('register_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $model         = new Register();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }
}
