<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyRequesterRequest;
use App\Http\Requests\StoreRequesterRequest;
use App\Http\Requests\UpdateRequesterRequest;
use App\Models\Requester;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class RequesterController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('requester_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $requesters = Requester::all();

        return view('admin.requesters.index', compact('requesters'));
    }

    public function create()
    {
        abort_if(Gate::denies('requester_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.requesters.create');
    }

    public function store(StoreRequesterRequest $request)
    {
        $requester = Requester::create($request->all());

        return redirect()->route('admin.requesters.index');
    }

    public function edit(Requester $requester)
    {
        abort_if(Gate::denies('requester_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.requesters.edit', compact('requester'));
    }

    public function update(UpdateRequesterRequest $request, Requester $requester)
    {
        $requester->update($request->all());

        return redirect()->route('admin.requesters.index');
    }

    public function show(Requester $requester)
    {
        abort_if(Gate::denies('requester_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.requesters.show', compact('requester'));
    }

    public function destroy(Requester $requester)
    {
        abort_if(Gate::denies('requester_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $requester->delete();

        return back();
    }

    public function massDestroy(MassDestroyRequesterRequest $request)
    {
        Requester::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
