<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyRrtRoleRequest;
use App\Http\Requests\StoreRrtRoleRequest;
use App\Http\Requests\UpdateRrtRoleRequest;
use App\Models\RrtRole;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class RrtRolesController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('rrt_role_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rrtRoles = RrtRole::all();

        return view('admin.rrtRoles.index', compact('rrtRoles'));
    }

    public function create()
    {
        abort_if(Gate::denies('rrt_role_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.rrtRoles.create');
    }

    public function store(StoreRrtRoleRequest $request)
    {
        $rrtRole = RrtRole::create($request->all());

        return redirect()->route('admin.rrt-roles.index');
    }

    public function edit(RrtRole $rrtRole)
    {
        abort_if(Gate::denies('rrt_role_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.rrtRoles.edit', compact('rrtRole'));
    }

    public function update(UpdateRrtRoleRequest $request, RrtRole $rrtRole)
    {
        $rrtRole->update($request->all());

        return redirect()->route('admin.rrt-roles.index');
    }

    public function show(RrtRole $rrtRole)
    {
        abort_if(Gate::denies('rrt_role_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.rrtRoles.show', compact('rrtRole'));
    }

    public function destroy(RrtRole $rrtRole)
    {
        abort_if(Gate::denies('rrt_role_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rrtRole->delete();

        return back();
    }

    public function massDestroy(MassDestroyRrtRoleRequest $request)
    {
        RrtRole::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
