<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyVaccinationationRequest;
use App\Http\Requests\StoreVaccinationationRequest;
use App\Http\Requests\UpdateVaccinationationRequest;
use App\Models\Vaccinationation;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class VaccinationationsController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('vaccinationation_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $vaccinationations = Vaccinationation::all();

        return view('admin.vaccinationations.index', compact('vaccinationations'));
    }

    public function create()
    {
        abort_if(Gate::denies('vaccinationation_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.vaccinationations.create');
    }

    public function store(StoreVaccinationationRequest $request)
    {
        $vaccinationation = Vaccinationation::create($request->all());

        return redirect()->route('admin.vaccinationations.index');
    }

    public function edit(Vaccinationation $vaccinationation)
    {
        abort_if(Gate::denies('vaccinationation_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.vaccinationations.edit', compact('vaccinationation'));
    }

    public function update(UpdateVaccinationationRequest $request, Vaccinationation $vaccinationation)
    {
        $vaccinationation->update($request->all());

        return redirect()->route('admin.vaccinationations.index');
    }

    public function show(Vaccinationation $vaccinationation)
    {
        abort_if(Gate::denies('vaccinationation_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.vaccinationations.show', compact('vaccinationation'));
    }

    public function destroy(Vaccinationation $vaccinationation)
    {
        abort_if(Gate::denies('vaccinationation_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $vaccinationation->delete();

        return back();
    }

    public function massDestroy(MassDestroyVaccinationationRequest $request)
    {
        Vaccinationation::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
