<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreAgencyRoleRequest;
use App\Http\Requests\UpdateAgencyRoleRequest;
use App\Http\Resources\Admin\AgencyRoleResource;
use App\Models\AgencyRole;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class AgencyRolesApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('agency_role_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new AgencyRoleResource(AgencyRole::all());
    }

    public function store(StoreAgencyRoleRequest $request)
    {
        $agencyRole = AgencyRole::create($request->all());

        return (new AgencyRoleResource($agencyRole))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(AgencyRole $agencyRole)
    {
        abort_if(Gate::denies('agency_role_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new AgencyRoleResource($agencyRole);
    }

    public function update(UpdateAgencyRoleRequest $request, AgencyRole $agencyRole)
    {
        $agencyRole->update($request->all());

        return (new AgencyRoleResource($agencyRole))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(AgencyRole $agencyRole)
    {
        abort_if(Gate::denies('agency_role_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $agencyRole->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
