<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreEmergencyResponseRequest;
use App\Http\Requests\UpdateEmergencyResponseRequest;
use App\Http\Resources\Admin\EmergencyResponseResource;
use App\Models\EmergencyResponse;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class EmergencyResponseApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('emergency_response_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new EmergencyResponseResource(EmergencyResponse::with(['domestic_emergency_response', 'cross_sectoral', 'response_to_international_emergencies', 'eoc_ims', 'vaccination_campaigns', 'emergency_leadership_role', 'multi_sectoral_emergency_response_plans', 'emergency_diseases'])->get());
    }

    public function store(StoreEmergencyResponseRequest $request)
    {
        $emergencyResponse = EmergencyResponse::create($request->all());
        $emergencyResponse->emergency_diseases()->sync($request->input('emergency_diseases', []));

        return (new EmergencyResponseResource($emergencyResponse))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(EmergencyResponse $emergencyResponse)
    {
        abort_if(Gate::denies('emergency_response_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new EmergencyResponseResource($emergencyResponse->load(['domestic_emergency_response', 'cross_sectoral', 'response_to_international_emergencies', 'eoc_ims', 'vaccination_campaigns', 'emergency_leadership_role', 'multi_sectoral_emergency_response_plans', 'emergency_diseases']));
    }

    public function update(UpdateEmergencyResponseRequest $request, EmergencyResponse $emergencyResponse)
    {
        $emergencyResponse->update($request->all());
        $emergencyResponse->emergency_diseases()->sync($request->input('emergency_diseases', []));

        return (new EmergencyResponseResource($emergencyResponse))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(EmergencyResponse $emergencyResponse)
    {
        abort_if(Gate::denies('emergency_response_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $emergencyResponse->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
