<?php

namespace App\Http\Requests;

use App\Models\DeploymentOpportunity;
use Gate;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Response;

class StoreDeploymentOpportunityRequest extends FormRequest
{
    public function authorize()
    {
        return Gate::allows('deployment_opportunity_create');
    }

    public function rules()
    {
        return [
            'name' => [
                'string',
                'required',
            ],
            'posting_number' => [
                'nullable',
                'integer',
                'min:-2147483648',
                'max:2147483647',
            ],
            'event_name' => [
                'string',
                'nullable',
            ],
            'deployer_position_title' => [
                'string',
                'nullable',
            ],
            'expected_deployment_start_date' => [
                'date_format:' . config('panel.date_format'),
                'nullable',
            ],
            'actual_deployment_start_date' => [
                'date_format:' . config('panel.date_format'),
                'nullable',
            ],
            'expected_deployment_end_date' => [
                'date_format:' . config('panel.date_format'),
                'nullable',
            ],
            'actual_deployment_end_date' => [
                'date_format:' . config('panel.date_format'),
                'nullable',
            ],
            'number_of_deployers' => [
                'nullable',
                'integer',
                'min:-2147483648',
                'max:2147483647',
            ],
            'location_city' => [
                'string',
                'nullable',
            ],
        ];
    }
}
