<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media;

class CaseManagement extends Model implements HasMedia
{
    use SoftDeletes;
    use InteractsWithMedia;
    use HasFactory;

    public $table = 'case_managements';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'physician_id',
        'case_management_specialty',
        'nurse_id',
        'nurse_speciality',
        'paramedic_id',
        'paramedic_specialty',
        'rapid_risk_assessments_id',
        'clinical_management_advice_and_recommendations_id',
        'icp_in_the_care_facility_id',
        'monitoring_system_id',
        'epidemic_survey_id',
        'determination_of_disease_status_id',
        'epidemiological_studies_id',
        'study_protocols_id',
        'data_collection_tools_id',
        'user_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function registerMediaConversions(Media $media = null): void
    {
        $this->addMediaConversion('thumb')->fit('crop', 50, 50);
        $this->addMediaConversion('preview')->fit('crop', 120, 120);
    }

    public function physician()
    {
        return $this->belongsTo(TrainingLevel::class, 'physician_id');
    }

    public function nurse()
    {
        return $this->belongsTo(TrainingLevel::class, 'nurse_id');
    }

    public function paramedic()
    {
        return $this->belongsTo(TrainingLevel::class, 'paramedic_id');
    }

    public function rapid_risk_assessments()
    {
        return $this->belongsTo(TrainingLevel::class, 'rapid_risk_assessments_id');
    }

    public function clinical_management_advice_and_recommendations()
    {
        return $this->belongsTo(TrainingLevel::class, 'clinical_management_advice_and_recommendations_id');
    }

    public function icp_in_the_care_facility()
    {
        return $this->belongsTo(TrainingLevel::class, 'icp_in_the_care_facility_id');
    }

    public function monitoring_system()
    {
        return $this->belongsTo(TrainingLevel::class, 'monitoring_system_id');
    }

    public function epidemic_survey()
    {
        return $this->belongsTo(TrainingLevel::class, 'epidemic_survey_id');
    }

    public function determination_of_disease_status()
    {
        return $this->belongsTo(TrainingLevel::class, 'determination_of_disease_status_id');
    }

    public function epidemiological_studies()
    {
        return $this->belongsTo(TrainingLevel::class, 'epidemiological_studies_id');
    }

    public function study_protocols()
    {
        return $this->belongsTo(TrainingLevel::class, 'study_protocols_id');
    }

    public function data_collection_tools()
    {
        return $this->belongsTo(TrainingLevel::class, 'data_collection_tools_id');
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
