<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class EmergencyLogistic extends Model
{
    use SoftDeletes;
    use HasFactory;

    public $table = 'emergency_logistics';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'shipping_and_receiving_id',
        'sample_packaging_id',
        'inventory_management_id',
        'travel_coordinator_id',
        'fleet_management_id',
        'moving_resources_to_the_field_id',
        'deployer_training_resources_id',
        'eoc_logistics_emergency_operations_center_id',
        'user_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function shipping_and_receiving()
    {
        return $this->belongsTo(TrainingLevel::class, 'shipping_and_receiving_id');
    }

    public function sample_packaging()
    {
        return $this->belongsTo(TrainingLevel::class, 'sample_packaging_id');
    }

    public function inventory_management()
    {
        return $this->belongsTo(TrainingLevel::class, 'inventory_management_id');
    }

    public function travel_coordinator()
    {
        return $this->belongsTo(TrainingLevel::class, 'travel_coordinator_id');
    }

    public function fleet_management()
    {
        return $this->belongsTo(TrainingLevel::class, 'fleet_management_id');
    }

    public function moving_resources_to_the_field()
    {
        return $this->belongsTo(TrainingLevel::class, 'moving_resources_to_the_field_id');
    }

    public function deployer_training_resources()
    {
        return $this->belongsTo(TrainingLevel::class, 'deployer_training_resources_id');
    }

    public function eoc_logistics_emergency_operations_center()
    {
        return $this->belongsTo(TrainingLevel::class, 'eoc_logistics_emergency_operations_center_id');
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
