<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class HazardousMaterialsExperience extends Model
{
    use SoftDeletes;
    use HasFactory;

    public $table = 'hazardous_materials_experiences';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'certified_hazardous_materials_manager_chmm_id',
        'certified_industrial_hygienist_cih_id',
        'hazmat_specialist_training_id',
        'record_keeping_id',
        'hazardous_materials_management_y_n_program_id',
        'medical_waste_plans_id',
        'spill_response_plans_id',
        'hazardous_waste_reduction_plans_id',
        'hazardous_waste_contingency_plans_id',
        'stormwater_y_n_plans_id',
        'occupational_health_and_safety_y_n_programs_id',
        'radiation_protection_plan_id',
        'collection_segregation_and_transport_of_hazardous_waste_id',
        'training_others_on_hazardous_waste_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function certified_hazardous_materials_manager_chmm()
    {
        return $this->belongsTo(TrainingLevel::class, 'certified_hazardous_materials_manager_chmm_id');
    }

    public function certified_industrial_hygienist_cih()
    {
        return $this->belongsTo(TrainingLevel::class, 'certified_industrial_hygienist_cih_id');
    }

    public function hazmat_specialist_training()
    {
        return $this->belongsTo(TrainingLevel::class, 'hazmat_specialist_training_id');
    }

    public function record_keeping()
    {
        return $this->belongsTo(TrainingLevel::class, 'record_keeping_id');
    }

    public function hazardous_materials_management_y_n_program()
    {
        return $this->belongsTo(TrainingLevel::class, 'hazardous_materials_management_y_n_program_id');
    }

    public function medical_waste_plans()
    {
        return $this->belongsTo(TrainingLevel::class, 'medical_waste_plans_id');
    }

    public function spill_response_plans()
    {
        return $this->belongsTo(TrainingLevel::class, 'spill_response_plans_id');
    }

    public function hazardous_waste_reduction_plans()
    {
        return $this->belongsTo(TrainingLevel::class, 'hazardous_waste_reduction_plans_id');
    }

    public function hazardous_waste_contingency_plans()
    {
        return $this->belongsTo(TrainingLevel::class, 'hazardous_waste_contingency_plans_id');
    }

    public function stormwater_y_n_plans()
    {
        return $this->belongsTo(TrainingLevel::class, 'stormwater_y_n_plans_id');
    }

    public function occupational_health_and_safety_y_n_programs()
    {
        return $this->belongsTo(TrainingLevel::class, 'occupational_health_and_safety_y_n_programs_id');
    }

    public function radiation_protection_plan()
    {
        return $this->belongsTo(TrainingLevel::class, 'radiation_protection_plan_id');
    }

    public function collection_segregation_and_transport_of_hazardous_waste()
    {
        return $this->belongsTo(TrainingLevel::class, 'collection_segregation_and_transport_of_hazardous_waste_id');
    }

    public function training_others_on_hazardous_waste()
    {
        return $this->belongsTo(TrainingLevel::class, 'training_others_on_hazardous_waste_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
