<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class InfectionPreventControl extends Model
{
    use SoftDeletes;
    use HasFactory;

    public $table = 'infection_prevent_controls';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'in_healthcare_settings_id',
        'in_a_non_medical_id',
        'outbreak_investigations_id',
        'facility_assessments_id',
        'developing_infection_prevention_id',
        'infection_prevention_and_control_id',
        'quality_improvement_id',
        'ppe_id',
        'point_of_entry_border_health_id',
        'poc_non_border_id',
        'rsi_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function in_healthcare_settings()
    {
        return $this->belongsTo(TrainingLevel::class, 'in_healthcare_settings_id');
    }

    public function in_a_non_medical()
    {
        return $this->belongsTo(TrainingLevel::class, 'in_a_non_medical_id');
    }

    public function outbreak_investigations()
    {
        return $this->belongsTo(TrainingLevel::class, 'outbreak_investigations_id');
    }

    public function facility_assessments()
    {
        return $this->belongsTo(TrainingLevel::class, 'facility_assessments_id');
    }

    public function developing_infection_prevention()
    {
        return $this->belongsTo(TrainingLevel::class, 'developing_infection_prevention_id');
    }

    public function infection_prevention_and_control()
    {
        return $this->belongsTo(TrainingLevel::class, 'infection_prevention_and_control_id');
    }

    public function quality_improvement()
    {
        return $this->belongsTo(TrainingLevel::class, 'quality_improvement_id');
    }

    public function ppe()
    {
        return $this->belongsTo(TrainingLevel::class, 'ppe_id');
    }

    public function point_of_entry_border_health()
    {
        return $this->belongsTo(TrainingLevel::class, 'point_of_entry_border_health_id');
    }

    public function poc_non_border()
    {
        return $this->belongsTo(TrainingLevel::class, 'poc_non_border_id');
    }

    public function rsi()
    {
        return $this->belongsTo(TrainingLevel::class, 'rsi_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
