@extends('layouts.admin')
@section('content')
<div class="content">

    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default">
                <div class="panel-heading">
                    {{ trans('global.edit') }} {{ trans('cruds.user.title_singular') }}
                </div>
                <div class="panel-body">
                    <form method="POST" action="{{ route("admin.users.update", [$user->id]) }}" enctype="multipart/form-data">
                        @method('PUT')
                        @csrf
                        <div class="form-group {{ $errors->has('name') ? 'has-error' : '' }}">
                            <label class="required" for="name">{{ trans('cruds.user.fields.name') }}</label>
                            <input class="form-control" type="text" name="name" id="name" value="{{ old('name', $user->name) }}" required>
                            @if($errors->has('name'))
                                <span class="help-block" role="alert">{{ $errors->first('name') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.user.fields.name_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('last_name') ? 'has-error' : '' }}">
                            <label class="required" for="last_name">{{ trans('cruds.user.fields.last_name') }}</label>
                            <input class="form-control" type="text" name="last_name" id="last_name" value="{{ old('last_name', $user->last_name) }}" required>
                            @if($errors->has('last_name'))
                                <span class="help-block" role="alert">{{ $errors->first('last_name') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.user.fields.last_name_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('middle_name') ? 'has-error' : '' }}">
                            <label for="middle_name">{{ trans('cruds.user.fields.middle_name') }}</label>
                            <input class="form-control" type="text" name="middle_name" id="middle_name" value="{{ old('middle_name', $user->middle_name) }}">
                            @if($errors->has('middle_name'))
                                <span class="help-block" role="alert">{{ $errors->first('middle_name') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.user.fields.middle_name_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('title') ? 'has-error' : '' }}">
                            <label>{{ trans('cruds.user.fields.title') }}</label>
                            <select class="form-control" name="title" id="title">
                                <option value disabled {{ old('title', null) === null ? 'selected' : '' }}>{{ trans('global.pleaseSelect') }}</option>
                                @foreach(App\Models\User::TITLE_SELECT as $key => $label)
                                    <option value="{{ $key }}" {{ old('title', $user->title) === (string) $key ? 'selected' : '' }}>{{ $label }}</option>
                                @endforeach
                            </select>
                            @if($errors->has('title'))
                                <span class="help-block" role="alert">{{ $errors->first('title') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.user.fields.title_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('sex') ? 'has-error' : '' }}">
                            <label class="required">{{ trans('cruds.user.fields.sex') }}</label>
                            <select class="form-control" name="sex" id="sex" required>
                                <option value disabled {{ old('sex', null) === null ? 'selected' : '' }}>{{ trans('global.pleaseSelect') }}</option>
                                @foreach(App\Models\User::SEX_SELECT as $key => $label)
                                    <option value="{{ $key }}" {{ old('sex', $user->sex) === (string) $key ? 'selected' : '' }}>{{ $label }}</option>
                                @endforeach
                            </select>
                            @if($errors->has('sex'))
                                <span class="help-block" role="alert">{{ $errors->first('sex') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.user.fields.sex_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('national_id_number') ? 'has-error' : '' }}">
                            <label class="required" for="national_id_number">{{ trans('cruds.user.fields.national_id_number') }}</label>
                            <input class="form-control" type="text" name="national_id_number" id="national_id_number" value="{{ old('national_id_number', $user->national_id_number) }}" required>
                            @if($errors->has('national_id_number'))
                                <span class="help-block" role="alert">{{ $errors->first('national_id_number') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.user.fields.national_id_number_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('service_number') ? 'has-error' : '' }}">
                            <label for="service_number">{{ trans('cruds.user.fields.service_number') }}</label>
                            <input class="form-control" type="text" name="service_number" id="service_number" value="{{ old('service_number', $user->service_number) }}">
                            @if($errors->has('service_number'))
                                <span class="help-block" role="alert">{{ $errors->first('service_number') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.user.fields.service_number_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('email') ? 'has-error' : '' }}">
                            <label class="required" for="email">{{ trans('cruds.user.fields.email') }}</label>
                            <input class="form-control" type="email" name="email" id="email" value="{{ old('email', $user->email) }}" required>
                            @if($errors->has('email'))
                                <span class="help-block" role="alert">{{ $errors->first('email') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.user.fields.email_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('password') ? 'has-error' : '' }}">
                            <label class="required" for="password">{{ trans('cruds.user.fields.password') }}</label>
                            <input class="form-control" type="password" name="password" id="password">
                            @if($errors->has('password'))
                                <span class="help-block" role="alert">{{ $errors->first('password') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.user.fields.password_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('roles') ? 'has-error' : '' }}">
                            <label class="required" for="roles">{{ trans('cruds.user.fields.roles') }}</label>
                            <div style="padding-bottom: 4px">
                                <span class="btn btn-info btn-xs select-all" style="border-radius: 0">{{ trans('global.select_all') }}</span>
                                <span class="btn btn-info btn-xs deselect-all" style="border-radius: 0">{{ trans('global.deselect_all') }}</span>
                            </div>
                            <select class="form-control select2" name="roles[]" id="roles" multiple required>
                                @foreach($roles as $id => $role)
                                    <option value="{{ $id }}" {{ (in_array($id, old('roles', [])) || $user->roles->contains($id)) ? 'selected' : '' }}>{{ $role }}</option>
                                @endforeach
                            </select>
                            @if($errors->has('roles'))
                                <span class="help-block" role="alert">{{ $errors->first('roles') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.user.fields.roles_helper') }}</span>
                        </div>
                        <div class="form-group {{ $errors->has('approved_for_roster') ? 'has-error' : '' }}">
                            <label>{{ trans('cruds.user.fields.approved_for_roster') }}</label>
                            @foreach(App\Models\User::APPROVED_FOR_ROSTER_RADIO as $key => $label)
                                <div>
                                    <input type="radio" id="approved_for_roster_{{ $key }}" name="approved_for_roster" value="{{ $key }}" {{ old('approved_for_roster', $user->approved_for_roster) === (string) $key ? 'checked' : '' }}>
                                    <label for="approved_for_roster_{{ $key }}" style="font-weight: 400">{{ $label }}</label>
                                </div>
                            @endforeach
                            @if($errors->has('approved_for_roster'))
                                <span class="help-block" role="alert">{{ $errors->first('approved_for_roster') }}</span>
                            @endif
                            <span class="help-block">{{ trans('cruds.user.fields.approved_for_roster_helper') }}</span>
                        </div>
                        <div class="form-group">
                            <button class="btn btn-danger" type="submit">
                                {{ trans('global.save') }}
                            </button>
                        </div>
                    </form>
                </div>
            </div>



        </div>
    </div>
</div>
@endsection